==> luminance-hdr_2.2.1.orig.tar.bz2: luminance-hdr-2.2.1/src/TonemappingOperators/reinhard05/tmo_reinhard05.h <==
/**
 * @file tmo_reinhard05.cpp
 * @brief Tone map XYZ channels using Reinhard05 model
 *
 * Dynamic Range Reduction Inspired by Photoreceptor Physiology.
 * E. Reinhard and K. Devlin.
 * In IEEE Transactions on Visualization and Computer Graphics, 2005.
 *
 * This file is a part of LuminanceHDR package, based on pfstmo.
 * ---------------------------------------------------------------------- 
 * Copyright (C) 2007 Grzegorz Krawczyk
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ---------------------------------------------------------------------- 
 * 
 * @author Grzegorz Krawczyk, <krawczyk@mpi-sb.mpg.de>
 *
 * $Id: tmo_reinhard05.h,v 1.2 2008/09/04 12:46:49 julians37 Exp $
 */

#ifndef _tmo_reinhard05_h_
#define _tmo_reinhard05_h_

/**
 * @brief: Tone mapping algorithm [Reinhard2005]
 *
 * @param width image width
 * @param height image height
 * @param R red channel
 * @param G green channel
 * @param B blue channel
 * @param Y luminance channel
 * @param br brightness level -8:8 (def 0)
 * @param ca amount of chromatic adaptation 0:1 (saturation, def 0)
 * @param la amount of light adaptation 0:1 (local/global, def 1)
 */

#include "Common/ProgressHelper.h"

void tmo_reinhard05(unsigned int width, unsigned int height,
  float* R, float* G, float* B, 
  const float* Y, float br, float ca, float la, ProgressHelper *ph );

#endif

==> luminance-hdr_2.3.0.orig.tar.bz2: luminance-hdr-2.3.0/src/TonemappingOperators/reinhard05/tmo_reinhard05.h <==
/**
 * @file tmo_reinhard05.cpp
 * @brief Tone map XYZ channels using Reinhard05 model
 *
 * Dynamic Range Reduction Inspired by Photoreceptor Physiology.
 * E. Reinhard and K. Devlin.
 * In IEEE Transactions on Visualization and Computer Graphics, 2005.
 *
 * This file is a part of LuminanceHDR package, based on pfstmo.
 * ---------------------------------------------------------------------- 
 * Copyright (C) 2007 Grzegorz Krawczyk
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ---------------------------------------------------------------------- 
 * 
 * @author Grzegorz Krawczyk, <krawczyk@mpi-sb.mpg.de>
 *
 * $Id: tmo_reinhard05.h,v 1.2 2008/09/04 12:46:49 julians37 Exp $
 */

#ifndef TMO_REINHARD05_H
#define TMO_REINHARD05_H

class ProgressHelper;

/**
 * @brief: Tone mapping algorithm [Reinhard2005]
 *
 * @param width image width
 * @param height image height
 * @param R red channel
 * @param G green channel
 * @param B blue channel
 * @param Y luminance channel
 * @param br brightness level -8:8 (def 0)
 * @param ca amount of chromatic adaptation 0:1 (saturation, def 0)
 * @param la amount of light adaptation 0:1 (local/global, def 1)
 */
void tmo_reinhard05(unsigned int width, unsigned int height,
  float* R, float* G, float* B, 
  const float* Y, float br, float ca, float la, ProgressHelper *ph );

#endif // TMO_REINHARD05_H
